# Quotes to Scrape

Login

“This life is what you make it. No matter what, you're going to mess up sometimes, it's a universal truth. But the good part is you get to decide how you're going to mess it up. Girls will be your friends - they'll act like it anyway. But just remember, some come, some go. The ones that stay with you through everything - they're your true best friends. Don't let go of them. Also remember, sisters make the best friends in the world. As for lovers, well, they'll come and go too. And baby, I hate to say it, most of them - actually pretty much all of them are going to break your heart, but you can't give up because if you give up, you'll never find your soulmate. You'll never find that half who makes you whole and that goes for everything. Just because you fail once, doesn't mean you're gonna fail at everything. Keep trying, hold on, and always, always, always believe in yourself, because if you don't, then who will, sweetie? So keep your head high, keep your chin up, and most importantly, keep smiling, because life's a beautiful thing and there's so much to smile about.” by Marilyn Monroe (about)
Tags: friends heartbreak inspirational life love sisters
“It takes a great deal of bravery to stand up to our enemies, but just as much to stand up to our friends.” by J.K. Rowling (about)
Tags: courage friends
“If you can't explain it to a six year old, you don't understand it yourself.” by Albert Einstein (about)
Tags: simplicity understand
“You may not be her first, her last, or her only. She loved before she may love again. But if she loves you now, what else matters? She's not perfect—you aren't either, and the two of you may never be perfect together but if she can make you laugh, cause you to think twice, and admit to being human and making mistakes, hold onto her and give her the most you can. She may not be thinking about you every second of the day, but she will give you a part of her that she knows you can break—her heart. So don't hurt her, don't change her, don't analyze and don't expect more than she can give. Smile when she makes you happy, let her know when she makes you mad, and miss her when she's not there.” by Bob Marley (about)
Tags: love
“I like nonsense, it wakes up the brain cells. Fantasy is a necessary ingredient in living.” by Dr. Seuss (about)
Tags: fantasy
“I may not have gone where I intended to go, but I think I have ended up where I needed to be.” by Douglas Adams (about)
Tags: life navigation
“The opposite of love is not hate, it's indifference. The opposite of art is not ugliness, it's indifference. The opposite of faith is not heresy, it's indifference. And the opposite of life is not death, it's indifference.” by Elie Wiesel (about)
Tags: activism apathy hate indifference inspirational love opposite philosophy
“It is not a lack of love, but a lack of friendship that makes unhappy marriages.” by Friedrich Nietzsche (about)
Tags: friendship lack-of-friendship lack-of-love love marriage unhappy-marriage
“Good friends, good books, and a sleepy conscience: this is the ideal life.” by Mark Twain (about)
Tags: books contentment friends friendship life
“Life is what happens to us while we are making other plans.” by Allen Saunders (about)
Tags: fate life misattributed-john-lennon planning plans

## Top Ten tags

love inspirational life humor books reading friendship friends truth simile